# VeraMind


The VeraMind is an open-source Python application built using the Hugging Face Transformers library and PyTorch. It leverages a pre-trained model (`VeraMind-Mini`) to predict whether a given news article is real or fake with a confidence score.

This project is licensed under the [Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 International (CC BY-NC-ND 4.0)](https://creativecommons.org/licenses/by-nc-nd/4.0/) license. You are free to use and share this model privately, but you must give appropriate credit, not use it for commercial purposes, and not distribute derivative works.

**Note:** This is a machine learning model and may make mistakes. It should not replace your own critical thinking when evaluating news authenticity. Always verify information from multiple reliable sources.

## Features

- Predicts if a given news article is real or fake.
- Provides a confidence score for the prediction.
- Utilizes the Hugging Face Transformers library for easy integration with other NLP models.

## Installation

1. Clone this repository:

```bash
git clone https://github.com/yourusername/VeraMind.git
cd VeraMind
```

2. Install the required dependencies:

```bash
pip install -r requirements.txt
```

## Usage

### Predicting News Authenticity

Here's how you can use the model to predict if a news article is real or fake:

```python
from src.Inference import VeraMindInference

# Load the model
model = VeraMindInference("path/to/VeraMind-Mini")

# Example news article text
text = "This is an example News Article"

# Predict if the news is real or fake
result = model.predict(text)

print(result)
```

The output will be a dictionary containing the result ("REAL" or "FAKE") and the confidence score:

```python
{'result': 'FAKE', 'confidence': 0.9990140199661255}
```

## Model Architecture

The `VeraMind-Mini` model used in this application is a fine-tuned version of the [DistilBERT](https://huggingface.co/distilbert-base-uncased) model for binary text classification. It's designed to distinguish between real and fake news articles.

## Disclaimer

This project is provided as-is, without any express or implied warranty. The maintainers are not responsible for any damages arising from the use of this software.

Always remember that machine learning models can make mistakes, so use this tool responsibly and critically evaluate its predictions.

## Citation

If you use this model in your research, please cite it as follows:

> **VeraMind News Authenticity Checker** (2024). Retrieved from https://gitea.fabelous.app/Fabel/VeraMind by Falko Habel